{
    "$graph": [
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/htseq-tool:2a8b0bfec9dc52aaeac29ee8e7ff3284e79553c0"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "function sum_file_array_size(farr) {\n  var divisor = 1048576;\n  var total = 0;\n  for (var i = 0; i<farr.length; i++) {\n    total += farr[i].size\n  } \n  return Math.ceil(total / divisor);\n} \n",
                        "function file_size_multiplier(fobj, mult) {\n  mult = typeof mult !== 'undefined' ? mult : 1;\n  var divisor = 1048576;\n  return Math.ceil(mult * fobj.size / divisor);\n} \n"
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 500,
                    "tmpdirMin": "$(sum_file_array_size([inputs.htseq_file, inputs.aggregate_length_file]) * 2)",
                    "outdirMin": "$(sum_file_array_size([inputs.htseq_file, inputs.aggregate_length_file]) * 2)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--aggregate_length_file"
                    },
                    "id": "#calculate_fpkm.cwl/aggregate_length_file"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "--htseq_counts"
                    },
                    "id": "#calculate_fpkm.cwl/htseq_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--output_prefix"
                    },
                    "id": "#calculate_fpkm.cwl/output_prefix"
                }
            ],
            "baseCommand": [
                "/opt/htseq-tools/venv/bin/htseq-tools",
                "fpkm"
            ],
            "id": "#calculate_fpkm.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix + '.FPKM.txt.gz')"
                    },
                    "id": "#calculate_fpkm.cwl/fpkm"
                },
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_prefix + '.FPKM-UQ.txt.gz')"
                    },
                    "id": "#calculate_fpkm.cwl/fpkm_uq"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/htseq-tool:2a8b0bfec9dc52aaeac29ee8e7ff3284e79553c0"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "function sum_file_array_size(farr) {\n  var divisor = 1048576;\n  var total = 0;\n  for (var i = 0; i<farr.length; i++) {\n    total += farr[i].size\n  } \n  return Math.ceil(total / divisor);\n} \n",
                        "function file_size_multiplier(fobj, mult) {\n  mult = typeof mult !== 'undefined' ? mult : 1;\n  var divisor = 1048576;\n  return Math.ceil(mult * fobj.size / divisor);\n} \n"
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 1000,
                    "tmpdirMin": "$(sum_file_array_size([inputs.bam_file, inputs.gtf_file]) * 1.1)",
                    "outdirMin": "$(sum_file_array_size([inputs.bam_file, inputs.gtf_file]) * 1.1)"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 7
                    },
                    "id": "#htseq_count.cwl/bam_file"
                },
                {
                    "type": "string",
                    "default": "exon",
                    "inputBinding": {
                        "prefix": "-t",
                        "position": 4
                    },
                    "id": "#htseq_count.cwl/feature_type"
                },
                {
                    "type": "string",
                    "default": "bam",
                    "inputBinding": {
                        "prefix": "-f",
                        "position": 0
                    },
                    "id": "#htseq_count.cwl/file_format"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "position": 8
                    },
                    "id": "#htseq_count.cwl/gtf_file"
                },
                {
                    "type": "string",
                    "default": "gene_id",
                    "inputBinding": {
                        "prefix": "-i",
                        "position": 5
                    },
                    "id": "#htseq_count.cwl/id_attr"
                },
                {
                    "type": "int",
                    "default": 10,
                    "inputBinding": {
                        "prefix": "-a",
                        "position": 3
                    },
                    "id": "#htseq_count.cwl/min_qual"
                },
                {
                    "type": "string",
                    "default": "intersection-nonempty",
                    "inputBinding": {
                        "prefix": "-m",
                        "position": 6
                    },
                    "id": "#htseq_count.cwl/mode"
                },
                {
                    "type": "string",
                    "id": "#htseq_count.cwl/output_filename"
                },
                {
                    "type": "string",
                    "default": "pos",
                    "inputBinding": {
                        "prefix": "-r",
                        "position": 1
                    },
                    "id": "#htseq_count.cwl/sort_order"
                },
                {
                    "type": "string",
                    "default": "no",
                    "inputBinding": {
                        "prefix": "-s",
                        "position": 2
                    },
                    "id": "#htseq_count.cwl/stranded"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "raw counts file",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#htseq_count.cwl/counts"
                }
            ],
            "stdout": "$(inputs.output_filename)",
            "baseCommand": [
                "htseq-count"
            ],
            "id": "#htseq_count.cwl"
        },
        {
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "DockerRequirement",
                    "dockerPull": "quay.io/ncigdc/htseq-tool:2a8b0bfec9dc52aaeac29ee8e7ff3284e79553c0"
                },
                {
                    "class": "InlineJavascriptRequirement",
                    "expressionLib": [
                        "function sum_file_array_size(farr) {\n  var divisor = 1048576;\n  var total = 0;\n  for (var i = 0; i<farr.length; i++) {\n    total += farr[i].size\n  } \n  return Math.ceil(total / divisor);\n} \n",
                        "function file_size_multiplier(fobj, mult) {\n  mult = typeof mult !== 'undefined' ? mult : 1;\n  var divisor = 1048576;\n  return Math.ceil(mult * fobj.size / divisor);\n} \n"
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "coresMin": 1,
                    "ramMin": 500,
                    "tmpdirMin": "$(sum_file_array_size(inputs.htseq_file) * 1.1)",
                    "outdirMin": "$(sum_file_array_size(inputs.htseq_file) * 1.1)"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File",
                        "inputBinding": {
                            "prefix": "--htseq_counts"
                        }
                    },
                    "id": "#merge_htseq.cwl/htseq_file"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "--out_file"
                    },
                    "id": "#merge_htseq.cwl/output_filename"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "doc": "merged counts file",
                    "outputBinding": {
                        "glob": "$(inputs.output_filename)"
                    },
                    "id": "#merge_htseq.cwl/counts"
                }
            ],
            "baseCommand": [
                "/opt/htseq-tools/venv/bin/htseq-tools",
                "merge_counts"
            ],
            "id": "#merge_htseq.cwl"
        },
        {
            "class": "Workflow",
            "requirements": [
                {
                    "class": "InlineJavascriptRequirement"
                },
                {
                    "class": "StepInputExpressionRequirement"
                },
                {
                    "class": "ScatterFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "id": "#main/bam_file"
                },
                {
                    "type": "File",
                    "id": "#main/gene_lengths"
                },
                {
                    "type": "File",
                    "id": "#main/gtf_file"
                },
                {
                    "type": "string",
                    "id": "#main/job_uuid"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/run_merge_counts/counts",
                    "id": "#main/htseq_counts"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fpkm/fpkm",
                    "id": "#main/htseq_fpkm"
                },
                {
                    "type": "File",
                    "outputSource": "#main/run_fpkm/fpkm_uq",
                    "id": "#main/htseq_fpkm_uq"
                }
            ],
            "steps": [
                {
                    "run": "#calculate_fpkm.cwl",
                    "in": [
                        {
                            "source": "#main/gene_lengths",
                            "id": "#main/run_fpkm/aggregate_length_file"
                        },
                        {
                            "source": "#main/run_merge_counts/counts",
                            "id": "#main/run_fpkm/htseq_file"
                        },
                        {
                            "source": "#main/job_uuid",
                            "id": "#main/run_fpkm/output_prefix"
                        }
                    ],
                    "out": [
                        "#main/run_fpkm/fpkm",
                        "#main/run_fpkm/fpkm_uq"
                    ],
                    "id": "#main/run_fpkm"
                },
                {
                    "run": "#htseq_count.cwl",
                    "scatter": [
                        "#main/run_htseq_counts/bam_file",
                        "#main/run_htseq_counts/output_filename"
                    ],
                    "scatterMethod": "dotproduct",
                    "in": [
                        {
                            "source": "#main/bam_file",
                            "id": "#main/run_htseq_counts/bam_file"
                        },
                        {
                            "source": "#main/gtf_file",
                            "id": "#main/run_htseq_counts/gtf_file"
                        },
                        {
                            "source": "#main/bam_file",
                            "valueFrom": "$(self.nameroot + '.htseq_counts.txt')",
                            "id": "#main/run_htseq_counts/output_filename"
                        },
                        {
                            "default": "name",
                            "id": "#main/run_htseq_counts/sort_order"
                        }
                    ],
                    "out": [
                        "#main/run_htseq_counts/counts"
                    ],
                    "id": "#main/run_htseq_counts"
                },
                {
                    "run": "#merge_htseq.cwl",
                    "in": [
                        {
                            "source": "#main/run_htseq_counts/counts",
                            "id": "#main/run_merge_counts/htseq_file"
                        },
                        {
                            "source": "#main/job_uuid",
                            "valueFrom": "$(self + '.htseq_counts.txt.gz')",
                            "id": "#main/run_merge_counts/output_filename"
                        }
                    ],
                    "out": [
                        "#main/run_merge_counts/counts"
                    ],
                    "id": "#main/run_merge_counts"
                }
            ],
            "id": "#main"
        }
    ],
    "cwlVersion": "v1.0"
}
